%define _disable_ld_no_undefined 1
%global __requires_exclude perl\\(Crypt::Cracklib\\)

Name:       heimdal
Version:    7.8.0
Release:    %mkrel 3
Summary:    Heimdal implementation of Kerberos V5 system
License:    BSD-like
Group:      Networking/Other
URL:        https://www.h5l.org/
Source0:    https://github.com/heimdal/heimdal/releases/download/heimdal-%{version}/heimdal-%{version}.tar.gz
Source1:    https://github.com/heimdal/heimdal/releases/download/heimdal-%{version}/heimdal-%{version}.tar.gz.sig
Source3:    %{name}.sysconfig
Source10:   %{name}.logrotate
Source26:   %{name}-kdc.service
Source27:   %{name}-ipropd-master.service
Source28:   %{name}-ipropd-slave.service
Source29:   %{name}-kadmind.service
Source30:   %{name}-kpasswdd.service
Source31:   %{name}-ipropd-slave-wrapper
Patch0:     cve-2022-45142.patch
Patch1:     1229.patch
Patch2:     heimdal-7.8.0-configure-clang16.patch
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xt)
BuildRequires:  db-devel >= 4.2.52
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  libtool
BuildRequires:  pkgconfig(ncurses) >= 5.3
BuildRequires:  openldap-devel >= 2.0
BuildRequires:  pkgconfig(readline)
BuildRequires:  pam-devel
BuildRequires:  e2fsprogs-devel
BuildRequires:  texinfo
BuildRequires:  pkgconfig(sqlite3)
#Required for tests/ldap
BuildRequires:  openldap-servers

%description
Kerberos 5 is a network authentication and single sign-on system.
Heimdal is a free Kerberos 5 implementation without export restrictions
written from the spec (rfc1510 and successors) including advanced features
like thread safety, IPv6, master-slave replication of Kerberos Key
Distribution Center server and support for ticket delegation (S4U2Self,
S4U2Proxy).

%package workstation
Summary:    Kerberos programs for use on workstations
Group:      Networking/Other
Requires:   %{name}-libs = %{version}-%{release}
Conflicts:  krb5-workstation
Provides:   kerberos-workstation

%description workstation
This package contains Kerberos 5 programs for use on workstations.

%package server
Summary:    Kerberos Server
Group:      System/Servers
Requires:   %{name}-libs = %{version}-%{release}
Requires:   krb5
Requires(post): chkconfig
Requires(preun):chkconfig
Conflicts:  krb5-server

%description server
This package contains the master KDC.

# Not working right yet
%if 0
%package hdb_ldap
Summary:    Kerberos Server LDAP Backend
Group:      System/Servers
Requires:   %{name}-server = %{version}-%{release}

%description hdb_ldap
This package contains the LDAP HDB backend plugin, which allows the use of
an LDAP server for storing the Heimdal database.
%endif

%package libs
Summary:    Heimdal shared libraries
Group:      System/Libraries
Conflicts:  %{_lib}gssapi2

%description libs
This package contains shared libraries required by several of the other
heimdal packages.

%package devel
Summary:    Header files for heimdal
Group:      System/Libraries
Requires:   %{name}-libs = %{version}-%{release}
Conflicts:  libxmlrpc-devel
Conflicts:  krb5-devel

%description devel
contains files needed to compile and link software using the kerberos
libraries.

%package devel-doc
Summary:    Developer documentation for heimdal
Group:      System/Libraries
Conflicts:  heimdal-devel <= 1.0.1-4

%description devel-doc
Contains the documentation covering functions etc. in the heimdal
libraries.

%prep
%autosetup -p1

%build
autoreconf -fi
%serverbuild
%configure \
    --with-hdbdir=%{_localstatedir}/lib/%{name} \
    --disable-static \
    --enable-shared \
    --with-readline \
    --with-readline-lib=%{_libdir} \
    --with-readline-include=%{_includedir}/readline \
    --with-openldap=%{_prefix} \
    --with-sqlite3=%{_prefix} \
    --with-libintl=%{_prefix} \
    --without-x \
    --with-ipv6 \
    --enable-kcm \
    --enable-pk-init
%if 0
    --enable-hdb-openldap-module
%endif
make

%install
install -d %{buildroot}%{_localstatedir}/lib/%{name}
#install -d %%{buildroot}%%{_sysconfdir}/%%{name}

%make_install

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 %{SOURCE26} %{buildroot}%{_unitdir}/heimdal-kdc.service
install -m 644 %{SOURCE27} %{buildroot}%{_unitdir}/heimdal-ipropd-master.service
install -m 644 %{SOURCE28} %{buildroot}%{_unitdir}/heimdal-ipropd-slave.service
install -m 644 %{SOURCE29} %{buildroot}%{_unitdir}/heimdal-kadmind.service
install -m 644 %{SOURCE30} %{buildroot}%{_unitdir}/heimdal-kpasswdd.service
install -m 755 %{SOURCE31} %{buildroot}%{_libexecdir}/ipropd-slave-wrapper

install -D -m 755 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -D -m 644 %{SOURCE10} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

chmod +r %{buildroot}%{_bindir}/otp   # qrde dlaczego to ma chmod 0

#touch %%{buildroot}%%{_sysconfdir}/%%{name}/krb5.keytab
touch %{buildroot}%{_sysconfdir}/krb5.keytab
touch %{buildroot}%{_localstatedir}/lib/%{name}/kadmind.acl

# prevent some conflicts
mv %{buildroot}%{_bindir}/su %{buildroot}%{_bindir}/ksu
mv %{buildroot}%{_mandir}/man1/su.1 %{buildroot}%{_mandir}/man1/ksu.1
rm -f %{buildroot}%{_mandir}/*5/ftpusers.5*

rm -f %{buildroot}%{_libdir}/lib{com_err,ss}.so
rm -f %{buildroot}%{_includedir}/{glob,fnmatch,ss/ss}.h
rm -f %{buildroot}%{_bindir}/mk_cmds

# see if we can avoid conflicting with krb5-devel
mv %{buildroot}/%{_bindir}/krb5-config %{buildroot}%{_bindir}/heimdal-config
%multiarch_binaries %{buildroot}%{_bindir}/heimdal-config

# utils
install -d -m 755 %{buildroot}%{_datadir}/%{name}
install -m 755 tools/kdc-log-analyze.pl %{buildroot}%{_datadir}/%{name}
install -m 755 lib/kadm5/check-cracklib.pl %{buildroot}%{_datadir}/%{name}
perl -pi -e 's|^#! ?/usr/pkg/bin/perl|#!%{_bindir}/perl|' \
    %{buildroot}%{_datadir}/%{name}/*.pl

# remove CAT files
rm -rf %{buildroot}%{_mandir}/cat*

# Remove libtool archives
find %{buildroot} -name '*.la' -delete


%check
%if %{?_with_test:1}%{!?_with_test:0}
# For some reason this check fails partially just under rpm:
perl -pi -e 's/check-iprop //g' tests/kdc/Makefile
make -C tests check
%endif

%post server
%_post_service %{name}-kdc

%preun server
%_preun_service %{name}-kdc

%files server
%doc NEWS TODO
%{_unitdir}/heimdal-kdc.service
%{_unitdir}/heimdal-ipropd-master.service
%{_unitdir}/heimdal-ipropd-slave.service
%{_unitdir}/heimdal-kadmind.service
%{_unitdir}/heimdal-kpasswdd.service
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %{_localstatedir}/lib/%{name}
%config(noreplace) %{_localstatedir}/lib/%{name}/kadmind.acl
# %%{_mandir}/*1/kimpersonate.1*
%{_mandir}/man8/kimpersonate.8.*
%{_mandir}/man8/iprop.8*
%{_mandir}/man8/iprop-log.8*
%{_mandir}/man8/kstash.8*
%{_mandir}/man8/hprop.8*
%{_mandir}/man8/hpropd.8*
%{_mandir}/man8/kadmind.8*
%{_mandir}/man8/kdc.8*
%{_mandir}/man8/kfd.8*
%{_mandir}/man8/kpasswdd.8*
%{_mandir}/man8/kcm.8*
%{_mandir}/man8/ipropd-*.8*
%{_sbindir}/kstash
%{_sbindir}/iprop-log
%{_libexecdir}/hprop
%{_libexecdir}/hpropd
%{_libexecdir}/ipropd-master
%{_libexecdir}/ipropd-slave
%{_libexecdir}/kadmind
%{_libexecdir}/kdc
%{_libexecdir}/kfd
%{_libexecdir}/kpasswdd
%{_libexecdir}/kcm
%{_libexecdir}/kimpersonate
%{_libexecdir}/ipropd-slave-wrapper
%{_datadir}/%{name}
%doc doc/*.html lib/hdb/hdb.schema

%if 0
%files hdb_ldap
%{_libdir}/hdb_ldap*
%endif

%files libs
%attr(400,root,root) %ghost %{_sysconfdir}/krb5.keytab
%{_bindir}/string2key
%{_bindir}/verify_krb5_conf
%{_libexecdir}/digest-service
%{_libexecdir}/kdigest
%{_libdir}/lib*.so.*
%{_libdir}/windc*.so.*
%{_infodir}/heimdal.info*
%{_infodir}/hx509.info.*
%{_mandir}/man5/qop.5*
%{_mandir}/man5/mech.5*
%{_mandir}/man8/kerberos.8*
%{_mandir}/man8/verify_krb5_conf.8*
%{_mandir}/man8/string2key.8*
%{_mandir}/man8/kdigest.8.*

%files workstation
%{_bindir}/afslog
%{_bindir}/bsearch
%{_bindir}/gsstool
%{_bindir}/heimtools
%{_bindir}/hxtool
%{_bindir}/idn-lookup
%{_bindir}/kdestroy
%{_bindir}/kf
%{_bindir}/kgetcred
%{_bindir}/kinit
%{_bindir}/klist
%{_bindir}/kpasswd
%attr(4755,root,root) %{_bindir}/ksu
%{_bindir}/kswitch
%attr(4755,root,root) %{_bindir}/otp
%{_bindir}/otpprint
%{_bindir}/pagsh
%{_bindir}/kadmin
%{_bindir}/ktutil
%{_mandir}/man1/afslog.1*
%{_mandir}/man1/bsearch.1*
%{_mandir}/man1/ksu.1*
%{_mandir}/man1/kdestroy.1*
%{_mandir}/man1/kgetcred.1*
%{_mandir}/man1/klist.1*
%{_mandir}/man1/kswitch.1*
%{_mandir}/man1/kinit.1*
%{_mandir}/man1/kpasswd.1*
%{_mandir}/man1/pagsh.1*
%{_mandir}/man1/otp.1*
%{_mandir}/man1/otpprint.1*
%{_mandir}/man1/kf.1*
%{_mandir}/man1/kadmin.1*
%{_mandir}/man1/ktutil.1*
%{_mandir}/man5/krb5.conf.5*

%files devel
%{_bindir}/heimdal-config
%multiarch_bindir/heimdal-config
%{_libdir}/lib*.so
%{_libdir}/windc.so
%{_includedir}/*
%{_libdir}/pkgconfig/heimdal-gssapi.pc
%{_libdir}/pkgconfig/heimdal-kadm-client.pc
%{_libdir}/pkgconfig/heimdal-kadm-server.pc
%{_libdir}/pkgconfig/heimdal-krb5.pc
%{_libdir}/pkgconfig/kadm-client.pc
%{_libdir}/pkgconfig/kadm-server.pc
%{_libdir}/pkgconfig/kafs.pc
%{_libdir}/pkgconfig/krb5-gssapi.pc
%{_libdir}/pkgconfig/krb5.pc
%{_libexecdir}/%{name}/asn1_compile
%{_libexecdir}/%{name}/asn1_print
%{_libexecdir}/%{name}/slc

%files devel-doc
%{_mandir}/man1/krb5-config.1*
%{_mandir}/man3/*
%{_mandir}/man7/*



%changelog
* Sun Oct 20 2024 daviddavid <daviddavid> 7.8.0-3.mga10
+ Revision: 2109004
- backport upstream patch to fix build

* Sat Feb 11 2023 guillomovitch <guillomovitch> 7.8.0-2.mga9
+ Revision: 1940248
- fix for CVE-2022-45142 (#31530)

* Sat Nov 19 2022 guillomovitch <guillomovitch> 7.8.0-1.mga9
+ Revision: 1908843
- new version 7.8.0

* Mon Oct 17 2022 guillomovitch <guillomovitch> 7.7.0-10.mga9
+ Revision: 1897390
- fix CVE-2022-31136

* Fri Sep 16 2022 neoclust <neoclust> 7.7.0-9.mga9
+ Revision: 1889157
- Rebuild against new openldap

* Wed Mar 30 2022 umeabot <umeabot> 7.7.0-8.mga9
+ Revision: 1834847
- Mageia 9 Mass Rebuild

* Sun Nov 28 2021 guillomovitch <guillomovitch> 7.7.0-7.mga9
+ Revision: 1759784
- add Debian patch to fix CVE-2021-3671
+ wally <wally>
- rebuild for openssl 3.0.0

* Mon Jan 04 2021 daviddavid <daviddavid> 7.7.0-5.mga8
+ Revision: 1668647
- drop the libtool archives

* Mon Dec 14 2020 neoclust <neoclust> 7.7.0-4.mga8
+ Revision: 1657125
- Rebuild as heimdal-devel cannot be installed

* Tue Feb 18 2020 umeabot <umeabot> 7.7.0-3.mga8
+ Revision: 1542173
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 7.7.0-2.mga8
+ Revision: 1475966
- rebuild for readline
+ wally <wally>
- replace deprecated %%makeinstall_std

* Mon Jul 08 2019 guillomovitch <guillomovitch> 7.7.0-1.mga8
+ Revision: 1419627
- new version 7.7.0

* Sat May 18 2019 guillomovitch <guillomovitch> 7.6.0-1.mga7
+ Revision: 1398234
- new version 7.6.0

* Sun Sep 23 2018 umeabot <umeabot> 7.5.0-2.mga7
+ Revision: 1298180
- Mageia 7 Mass Rebuild

* Wed Dec 13 2017 guillomovitch <guillomovitch> 7.5.0-1.mga7
+ Revision: 1182508
- new version 7.5.0

* Tue Sep 05 2017 cjw <cjw> 7.4.0-2.mga7
+ Revision: 1151486
- rebuild for openssl 1.1

* Sun Jul 16 2017 guillomovitch <guillomovitch> 7.4.0-1.mga7
+ Revision: 1123872
- new version 7.4.0

* Wed May 03 2017 guillomovitch <guillomovitch> 7.3.0-1.mga6
+ Revision: 1098826
- new version 7.3.0

* Sun Feb 19 2017 guillomovitch <guillomovitch> 7.1.0-1.mga6
+ Revision: 1086940
- new version 7.1.0

* Mon Feb 15 2016 luigiwalser <luigiwalser> 1.5.3-7.mga6
+ Revision: 960704
- fix linking with pthread
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.5.3-6.mga5
+ Revision: 740009
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.5.3-5.mga5
+ Revision: 680105
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 1.5.3-4.mga4
+ Revision: 540513
- Mageia 4 Mass Rebuild

* Tue Oct 08 2013 colin <colin> 1.5.3-3.mga4
+ Revision: 493754
- Rebuild against ncurse's libtinfo rather than libtermcap

* Fri Sep 27 2013 nanardon <nanardon> 1.5.3-2.mga4
+ Revision: 488009
- rebuild to fix provides

* Wed Sep 11 2013 fwang <fwang> 1.5.3-1.mga4
+ Revision: 477477
- do not build docs
- add texi fixes from debian

* Tue Mar 12 2013 guillomovitch <guillomovitch> 1.5.3-1.mga3
+ Revision: 402199
- new version

* Sat Jan 12 2013 umeabot <umeabot> 1.5.2-5.mga3
+ Revision: 353158
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jul 31 2012 fwang <fwang> 1.5.2-4.mga3
+ Revision: 276370
- rebuild for db-5.3

* Thu Jul 12 2012 colin <colin> 1.5.2-3.mga3
+ Revision: 270440
- Disable the -login package. It cannot be installed

* Thu Jul 12 2012 colin <colin> 1.5.2-2.mga3
+ Revision: 270436
- Do not replace system su, use ksu

* Mon Jan 16 2012 guillomovitch <guillomovitch> 1.5.2-1.mga2
+ Revision: 196885
- new version

* Mon Oct 03 2011 guillomovitch <guillomovitch> 1.5.1-1.mga2
+ Revision: 151385
- new version
- add Short-Description header to init script
- new  version
- new version
+ dmorgan <dmorgan>
- imported package heimdal


* Tue May 11 2010 Buchan Milne <bgmilne@mandriva.org> 1.3.2-3mdv2010.1
+ Revision: 544535
- Search samba accounts by filtering on uid equal to userid, not princname

* Wed Apr 28 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.3.2-2mdv2010.1
+ Revision: 540281
- fix build with openssl 1.0
- add telnet-server and telnet-client virtual packages
- conflict with other telnet packages

* Fri Mar 26 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.3.2-1mdv2010.1
+ Revision: 527600
- new version

* Sun Feb 14 2010 Buchan Milne <bgmilne@mandriva.org> 1.3.1-4mdv2010.1
+ Revision: 505977
- Use system libcom_err again (fixes conflict between -server libext2fs-devel)

* Mon Feb 08 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.3.1-3mdv2010.1
+ Revision: 502234
- fix exported symbols list (should fix smbk5pwd overlay)
- no need to prevent init script translation

* Thu Dec 31 2009 Funda Wang <fwang@mandriva.org> 1.3.1-2mdv2010.1
+ Revision: 484334
- rebuild for db4.8

* Mon Nov 23 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.3.1-1mdv2010.1
+ Revision: 469224
- update to new version 1.3.1

* Thu Nov 19 2009 Zombie Ryushu <ryushu@mandriva.org> 1.3.0-1mdv2010.1
+ Revision: 467455
- Fix man pages
- Fix files section
- Fix files section
- Upgrade to 1.3.0 stable from rc1
- Upgrade to 1.3.0 stable from rc1

* Tue Oct 13 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.3.0-0.rc1.1mdv2010.0
+ Revision: 457005
- new version

* Tue Oct 06 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.3.0-0.pre10.1mdv2010.0
+ Revision: 455249
- new pre-release

* Fri Aug 28 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.3.0-0.pre6.1mdv2010.0
+ Revision: 421808
- new version
- drop unused sources
- cleanup patch set

* Wed Feb 25 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.2.1-2mdv2009.1
+ Revision: 344919
- rebuild against new readline
- fix format errors

* Sat Nov 08 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.2.1-1mdv2009.1
+ Revision: 301107
- update to new version 1.2.1

* Mon Oct 27 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.2-6mdv2009.1
+ Revision: 297548
- fix perl scripts interpreter, and install password check plugin

* Sun Oct 26 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.2-5mdv2009.1
+ Revision: 297291
- ship utility scripts in server package

* Wed Oct 01 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.2-4mdv2009.0
+ Revision: 290690
- conflict with openafs has been fixed

* Tue Jul 15 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.2-3mdv2009.0
+ Revision: 235929
- mark /etc/sysconfig/heimdal as configuration file

* Tue Jul 15 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.2-2mdv2009.0
+ Revision: 235889
- fix default database location

* Wed Jul 02 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.2-1mdv2009.0
+ Revision: 230714
- new version

  + Buchan Milne <bgmilne@mandriva.org>
    - New version 1.2
      Address some overlinking/underlinking issues (not all fixed yet)
      Build against system sqlite

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers
    - normalize call to ldconfig in %%post/%%postun
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Mon Mar 10 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.1-4mdv2008.1
+ Revision: 183582
- move headers back to standard location
  make devel package conflict with mit-kerberos devel package

* Fri Mar 07 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.1-3mdv2008.1
+ Revision: 181388
- don't redefine rpm macros, it break readline detection
- rediff readline test fix using automake source files
- use PLD patch to avoid install libeditline, so as to fix conflict with readline

* Mon Feb 18 2008 Thierry Vignaud <tv@mandriva.org> 1.1-2mdv2008.1
+ Revision: 170887
- rebuild
- fix "foobar is blabla" summary (=> "blabla") so that it looks nice in rpmdrake
- fix summary-not-capitalized

* Fri Jan 25 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.1-1mdv2008.1
+ Revision: 158141
- new version
  drop patch 8 and 9 (merged upstream)
  drop additional sources
  only use specific library directory for releases <= 2007.1

  + Buchan Milne <bgmilne@mandriva.org>
    - Improve descriptions
    - Add chkconfig lines for distros that dont yet support LSB tags
    - Remove attributions, as it no longer resembles the script attributed to.

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Dec 24 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.2-2mdv2008.1
+ Revision: 137508
- rebuilt against openldap-2.4.7 libs

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Dec 17 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.0.2-1mdv2008.1
+ Revision: 121654
- new version

* Sun Dec 09 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.0.2-0.RC6.1mdv2008.1
+ Revision: 116778
- new version

  + Thierry Vignaud <tv@mandriva.org>
    - buildrequires X11-devel instead of XFree86-devel

  + Buchan Milne <bgmilne@mandriva.org>
    - Use --detach for ipropd-master by default
    - Avoid conflict with krb5-devel, by:
     - moving headers to %%_includedir/heimdal
     - splitting of the devel docs
     - renaming krb5-config to heimdal-config

* Thu Sep 27 2007 Buchan Milne <bgmilne@mandriva.org> 1.0.1-4mdv2008.0
+ Revision: 93260
- Dont run tests by default
- Buildrequire texinfo for docs
- Conflict with libgssapi2 on 2008.0 to take care of upgrade case
- Ship schema file (hdb.schema) for hdb_ldap
- Start and stop all relevant daemons in init script (configurable)
- Fix start/stop messages in init script (part of bug #32897)
- Require krb5 on mdv2008.0 or later (part of bug #27273)
- Fix location of configuration files (bug #32898)
- Ship some files in svn but missing from tarball, among others to
  - ship html docs
  - ship files necessary for tests
- Enable tests (except for check-ipropd which fails only under rpm)
- Make backports work (by shipping libs in package-specific dir) on 2007.1 or older

* Sun Sep 09 2007 Buchan Milne <bgmilne@mandriva.org> 1.0.1-3mdv2008.0
+ Revision: 83707
- Buildrequire e2fsprogs-devel (fixes #32110)

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - adjust conflict on libxmlrpc-devel

* Thu Aug 23 2007 Thierry Vignaud <tv@mandriva.org> 1.0.1-2mdv2008.0
+ Revision: 70270
- kill file require on chkconfig

* Thu Aug 16 2007 Buchan Milne <bgmilne@mandriva.org> 1.0.1-1mdv2008.0
+ Revision: 64524
- New version 1.0.1
- Fix daemons detaching from init script (#27274)
- Add conflict with ftp-client-krb5 (#23757)
- Add conflicts to heimdal-login (is probably totally uninstallable now) (#23759)
- Add conflict with telnet-client-krb5 (#23763)
- Drop ftpusers file conflicting with man-pages (#32181)
- Buildrequire readline devel (fixes conflict with editline) (#25605)

* Tue Jun 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.1-4mdv2008.0
+ Revision: 41558
- explicit conflicts from devel package with krb5-devel and gssapi-devel

* Mon Jun 04 2007 Buchan Milne <bgmilne@mandriva.org> 0.8.1-3mdv2008.0
+ Revision: 35100
- BuildRequire openldap-devel so --with-openldap has a chance of working

* Fri Apr 27 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.1-2mdv2008.0
+ Revision: 18677
- get rid of heimdal mk_cmds to fix ext2fs-devel conflict, and explicit conflict with xmlrpc-devel

* Fri Apr 27 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.8.1-1mdv2008.0
+ Revision: 18510
- new version


* Tue Mar 20 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.7.2-5mdv2007.1
+ Revision: 147013
- drop unapplied patches, bunzip remaining one
- fix database location
  use standard compilation flags, execepted fortify flags

* Wed Mar 14 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.7.2-4mdv2007.1
+ Revision: 143504
- fix build dependencies
- make sure the lib package doesn't conflict with its mit equivalent, while the workstation and the server one does
- make workstation package provides kerberos-workstation
- move data into more compliant %%{_localstatedir}/%%{name}
- drop alternatives, use plain old conflicts with krb5 and openafs
- rename base package into -workstation, as for the MIT implementation
- minor spec cleanups
- yet another polish description slaid
- cleanup %%file sections
- drop polish translations (if i was not so lazy, I'd move them to rpm-summary package)

* Thu Feb 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.7.2-3mdv2007.1
+ Revision: 124675
- explicit conflict with MITH telnet and ftp server
- fix alternative problem (fix #28856)

  + Buchan Milne <bgmilne@mandriva.org>
    - Import heimdal

* Thu Aug 24 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.7.2-2mdv2007.0
- fix group

* Thu Mar 23 2006 Buchan Milne <bgmilne@mandriva.org> 0.7.2-1mdk
- New release 0.7.2
- buildrequire bison

* Thu Sep 22 2005 Buchan Milne <bgmilne@mandriva.org> 0.7.1-1mdk
- finally finish the last bits of this initial package

* Fri Nov 26 2004 Buchan Milne <bgmilne@linux-mandrake.com> 0.6.3-1mdk
- 0.6.3

* Tue Jul 27 2004 Buchan Milne <bgmilne@linux-mandrake.com> 0.6.2-1mdk
- 0.6.2
- drop db4 patchs (p3,p4) and compilation fixes (p5) - applied upstream

